import {
  DeleteButton,
  EditButton,
  List,
  ShowButton,
  useTable,
} from "@refinedev/antd";
import type { BaseRecord } from "@refinedev/core";
import { Space, Table, Tag, Button, Tooltip, Typography } from "antd";
import { PlusOutlined, ApiOutlined, ForkOutlined, LockOutlined } from '@ant-design/icons';

const { Title } = Typography;

export const TemplateList = () => {
  const { tableProps } = useTable({
    syncWithLocation: true,
  });

  return (
    <>
      <div style={{ display: "flex", justifyContent: "space-between", alignItems: "center", marginBottom: 16 }}>
        <Title level={4}>Deployment Templates</Title>
        <Button type="primary" icon={<PlusOutlined />} href="/templates/create">
          Create New Template
        </Button>
      </div>

      <List>
        <Table {...tableProps} rowKey="id">
          <Table.Column dataIndex="id" title="ID" />
          <Table.Column 
            dataIndex="name" 
            title="Template Name"
            sorter={(a, b) => a.name.localeCompare(b.name)}
          />
          <Table.Column dataIndex="description" title="Description" />
          <Table.Column 
            title="App Count" 
            render={(_, record: any) => (
              record?.config?.apps?.length || 0
            )}
          />
          <Table.Column 
            title="Features" 
            render={(_, record: any) => (
              <Space>
                {record?.config?.networkPolicies?.length > 0 && (
                  <Tooltip title="Network Policies">
                    <ForkOutlined style={{ color: '#1890ff' }} />
                  </Tooltip>
                )}
                {record?.config?.envVariables && Object.keys(record.config.envVariables).length > 0 && (
                  <Tooltip title="Environment Variables">
                    <ApiOutlined style={{ color: '#52c41a' }} />
                  </Tooltip>
                )}
                {record?.config?.secrets?.length > 0 && (
                  <Tooltip title="Secret Configuration">
                    <LockOutlined style={{ color: '#fa8c16' }} />
                  </Tooltip>
                )}
              </Space>
            )}
          />
          <Table.Column dataIndex="version" title="Version" />
          <Table.Column 
            dataIndex="createdBy" 
            title="Created By" 
            render={(value) => (
              <span>{value || "System"}</span>
            )}
          />
          <Table.Column
            title="Actions"
            dataIndex="actions"
            render={(_, record: BaseRecord) => (
              <Space>
                <ShowButton hideText size="small" recordItemId={record.id} />
                <EditButton hideText size="small" recordItemId={record.id} />
                <DeleteButton hideText size="small" recordItemId={record.id} />
              </Space>
            )}
          />
        </Table>
      </List>
    </>
  );
};