/**
 * Deployment data model that matches the UI components in the deployments section
 */
export interface Deployment {
  id: string;
  name: string;
  clientId: string;
  clientName?: string;
  templateId: string;
  status: DeploymentStatus;
  version: string;
  environment: Environment;
  containerCount: number;
  
  // Status & monitoring info
  healthStatus?: HealthStatus;
  cpuUsage?: number;
  memoryUsage?: number;
  storageUsage?: number;
  
  // Dates
  deploymentDate: string;
  updatedAt: string;
  createdAt: string;
  
  // Relationships
  deployedApps?: DeployedApp[];
}

export type DeploymentStatus = 
  | 'pending'
  | 'deploying'
  | 'active'
  | 'failed'
  | 'updating'
  | 'deleting';

export type Environment = 
  | 'development'
  | 'staging'
  | 'production';

export type HealthStatus = 
  | 'healthy'
  | 'degraded'
  | 'unhealthy';

export interface DeployedApp {
  appId: string;
  status: AppDeploymentStatus;
  version: string;
  url?: string;
  podCount?: number;
  healthStatus?: HealthStatus;
  configSnapshot: string;
}

export type AppDeploymentStatus = 
  | 'pending'
  | 'running'
  | 'failed'
  | 'scaling'
  | 'updating';

export interface DeploymentFormData {
  name: string;
  clientId: string;
  templateId: string;
  version: string;
  containerCount: number;
  environment: Environment;
}