/**
 * Template data model that matches the Golang backend implementation
 */
export interface Template {
  id: string;
  name: string;
  description: string;
  version: string;
  
  // Configuration
  config: TemplateConfig;
  
  // Metadata
  createdAt: string;
  updatedAt: string;
  createdBy: string;
  
  // Relationships
  deployments?: Deployment[];
}

export interface TemplateConfig {
  apps: AppConfig[];
  networkPolicies: NetworkPolicy[];
  envVariables?: Record<string, string>;
  secrets?: SecretConfig[];
}

export interface AppConfig {
  id: string;
  name: string;
  exposedPorts?: number[];
  publicAccess: boolean;
  resources: ResourceConfig;
  autoscaling?: AutoscalingConfig;
  envOverrides?: Record<string, string>;
  serviceMesh: boolean;
}

export interface ResourceConfig {
  cpu: string;
  memory: string;
  storage: string;
}

export interface AutoscalingConfig {
  enabled: boolean;
  minReplicas: number;
  maxReplicas: number;
  cpuThreshold: number;
  metric: string;
}

export interface NetworkPolicy {
  name: string;
  fromApps: string[];
  toApps: string[];
  ports?: number[];
  allowEgress: boolean;
}

export interface SecretConfig {
  name: string;
  description: string;
  required: boolean;
}

// For integration with existing components
export interface Deployment {
  id: string;
  name: string;
  // Additional fields omitted for brevity
}

/**
 * Template form data for creating/editing templates
 */
export interface TemplateFormData {
  name: string;
  description: string;
  version: string;
  config: TemplateConfig;
}